Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2013-10-26 05:06:19 +0400
committerCampbell Barton <ideasman42@gmail.com>2013-10-26 05:06:19 +0400
commit48c1e0c0fcb66502026721a50ae5e17470aee816 (patch)
tree94e812e78479df2d84dc8d0faccad212ca6fde56 /source/blender/blenlib/BLI_task.h
parent00160d4a1be401b789bc470cc397b1172353b116 (diff)
spelling: use American spelling for canceled
Diffstat (limited to 'source/blender/blenlib/BLI_task.h')
-rw-r--r--source/blender/blenlib/BLI_task.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/source/blender/blenlib/BLI_task.h b/source/blender/blenlib/BLI_task.h
index f57d42858c7..c9cbaf997fb 100644
--- a/source/blender/blenlib/BLI_task.h
+++ b/source/blender/blenlib/BLI_task.h
@@ -88,8 +88,8 @@ void BLI_task_pool_cancel(TaskPool *pool);
/* stop all worker threads */
void BLI_task_pool_stop(TaskPool *pool);
-/* for worker threads, test if cancelled */
-bool BLI_task_pool_cancelled(TaskPool *pool);
+/* for worker threads, test if canceled */
+bool BLI_task_pool_canceled(TaskPool *pool);
/* optional userdata pointer to pass along to run function */
void *BLI_task_pool_userdata(TaskPool *pool);